/*
 * draw.h
 *
 * Copyright (C) 2002 Thomas Graf <tgr@kaosu.ch>
 */

#ifndef __BMON_DRAW_H_
#define __BMON_DRAW_H_

#include "bmon.h"

extern int row;


enum bandwidth {
    overview,
    detailed,
    graphic
};


enum graphic {
    minute,
    hour,
    day
};

enum unit {
    dyanmic,
    byte,
    kilobyte,
    megabyte,
    gigabyte,
    terabyte
};



/*
 * handles user input:
 *  - change selected interface
 *  - change modes (overview, graphical, detailed)
 *  - change unit (seconds, minutes, hours)
 *
 *  Keys:
 *   'o'          overview mode
 *   'd'          detailed mode
 *   'g' or <CR>  graphical mode
 *   'S'          unit -> seconds
 *   'M'          unit -> minutes
 *   'H'          unit -> hours
 *   Up           previous interface
 *   Down         next interface
 *   Left         previous unit
 *   Right        next unit
 *   '0'-'9'      jump to interface entry n
 *
 * Returns 1 if you should redraw the screen (i.e. call intf_draw())
 * otherwise 0.
 */
#ifdef HAVE_CURSES
int intf_handle_input(int ch);


/*
 * draws the current selected mode to the current curses screen
 */
void intf_draw(void);
#endif


void intf_draw_ascii(void);
void intf_draw_html(const char *path);


#endif
